<?php
/**
 * Created by PhpStorm.
 * User: davidkryzaniak
 * Date: 02/11/2014
 * Time: 23:25
 */

class horizontalSubscribeSettingsPage
{
	/**
	 * Holds the values to be used in the fields callbacks
	 */
	private $options;
	private $DEFAULT_LINE_HEIGHT = 25; //default line height

	/**
	 * Start up
	 */
	public function __construct()
	{
		add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );
		add_action( 'admin_init', array( $this, 'page_init' ) );
	}

	/**
	 * Add options page
	 */
	public function add_plugin_page()
	{
		// This page will be under "Appearance"
		add_submenu_page(
			'themes.php',
			'Settings Admin',
			'GNT: Horizontal Subscribe',
			'manage_options',
			'gnt-horizontal-subscribe-settings',
			array( $this, 'create_admin_page' )
		);
	}

	/**
	 * Options page callback
	 */
	public function create_admin_page()
	{
		// Set class property
		$this->options = get_option( 'gnt_horizontal_subscribe' );
		?>
		<div class="wrap">
			<form method="post" action="options.php">
				<?php
				// This prints out all hidden setting fields
				settings_fields( 'gnt_horizontal_subscribe_option_group' );
				do_settings_sections( 'gnt-horizontal-subscribe-settings' );
				submit_button();
				?>
			</form>
		</div>
	<?php
	}

	/**
	 * Register and add settings
	 */
	public function page_init()
	{
		register_setting(
			'gnt_horizontal_subscribe_option_group', // Option group
			'gnt_horizontal_subscribe', // Option name
			array( $this, 'sanitize' ) // Sanitize
		);

		add_settings_section(
			'setting_section_id', // ID
			'Get Noticed Theme: Horizontal Subscribe Bar Settings', // Title
			array( $this, 'print_section_info' ), // Callback
			'gnt-horizontal-subscribe-settings' // Page
		);

		add_settings_field(
			'signup_form', // ID
			'Subscribe Embed Code', // Title
			array( $this, 'signup_form_callback' ), // Callback
			'gnt-horizontal-subscribe-settings', // Page
			'setting_section_id' // Section
		);

		add_settings_field(
			'title',
			'Header Message',
			array( $this, 'title_callback' ),
			'gnt-horizontal-subscribe-settings',
			'setting_section_id'
		);

		add_settings_field(
			'line_height',
			'Submit Button Height (Default: 25)',
			array( $this, 'line_height_callback' ),
			'gnt-horizontal-subscribe-settings',
			'setting_section_id'
		);
	}

	/**
	 * Sanitize each setting field as needed
	 *
	 * @param array $input Contains all settings fields as array keys
	 * @return array Cleaned array of POST Values
	 */
	public function sanitize( $input )
	{
		$new_input = array();
		if( isset( $input['signup_form'] ) )
			$new_input['signup_form'] =  $this->cleanSignupForm($input['signup_form']);

		if( isset( $input['title'] ) )
			$new_input['title'] = sanitize_text_field( $input['title'] );

		if( isset( $input['line_height'] ) )
			$new_input['line_height'] =
				(is_numeric(trim($input['line_height'])) ? trim($input['line_height']) : $this->DEFAULT_LINE_HEIGHT);

		return $new_input;
	}

	private function cleanSignupForm($rawinput)
	{
		return $rawinput;
	}

	/**
	 * Print the Section text
	 */
	public function print_section_info()
	{
		print '<style>.form-table textarea,.form-table input[type=text]{width:100%}</style>';
		print '<p><strong style="color:darkred">Please note:</strong> This version of the Horizontal Subscribe Bar has only been tested with ';
		print 'MailChimp\'s embed form. Support for ConstantContant (and other email services) is coming soon. <p>';
		print '<p>It\'s recommended that you generate a new "Naked" signup form, with "only required fields" shown and no title. ';
		print '<a href="https://www.dropbox.com/s/6v9pyzkjqxsjp32/Screenshot%202014-11-03%2013.51.44.png?dl=0" target="_blank">MailChimp Example Settings</a></p>';
		print '<p>Have a question? <a href="https://davekz.com/connect/" target="_blank">Contact me</a></p>';
	}

	/**
	 * Get the settings option array and print one of its values
	 */
	public function signup_form_callback()
	{
		printf(
			'<textarea id="signup_form" style="height:250px" name="gnt_horizontal_subscribe[signup_form]">%s</textarea>',
			isset( $this->options['signup_form'] ) ? esc_attr( $this->options['signup_form']) : ''
		);
	}

	/**
	 * Get the settings option array and print one of its values
	 */
	public function title_callback()
	{
		printf(
			'<input type="text" id="title" placeholder="Example: Sign up for email updates!" required="required" name="gnt_horizontal_subscribe[title]" value="%s" />',
			isset( $this->options['title'] ) ? esc_attr( $this->options['title']) : ''
		);
	}

	/**
	 * Get the settings option array and print one of its values
	 */
	public function line_height_callback()
	{
		printf(
			'<input type="number" id="line_height" placeholder="Sign up for email updates!" required="required" name="gnt_horizontal_subscribe[line_height]" value="%s" />',
			isset( $this->options['line_height'] ) ? esc_attr( $this->options['line_height']) : '25'
		);
	}

}